package org.ogce.xregistry.security;

import java.io.InputStream;
import java.security.GeneralSecurityException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.List;

import org.globus.gsi.CertUtil;

/**
 * @author Satoshi Shirasuna
 */
public class CertificateManager {
 
    private static X509Certificate[] trustedCertificates;

    /**
     * Load CA certificates from a file included in the XBaya jar.
     * 
     * @return The trusted certificates.
     */
    public static X509Certificate[] getTrustedCertificates(String trustedcafile) {
    	ClassLoader classLoader = Thread.currentThread().getContextClassLoader();
    	InputStream stream = classLoader.getResourceAsStream(trustedcafile);
        if (stream == null) {
            throw new RuntimeException("Failed to get InputStream to "
                    + trustedcafile);
        }
        List<X509Certificate> trustedCertificatesList = readTrustedCertificates(stream);
        return trustedCertificatesList.toArray(new X509Certificate[trustedCertificatesList.size()]);
    }
    
    /**
     * @param stream
     * @return List of X509Certificate
     */
    public static List<X509Certificate> readTrustedCertificates(InputStream stream) {
        ArrayList<X509Certificate> certificates = new ArrayList<X509Certificate>();
        while (true) {
            X509Certificate certificate;
            try {
                certificate = CertUtil.loadCertificate(stream);
            }catch (GeneralSecurityException e) {
                String message = "Certificates are invalid";
                throw new RuntimeException(message, e);
            }
            if (certificate == null) {
                break;
            }
            certificates.add(certificate);
        }
        return certificates;
    }

}

